@@ -50,12 +50,13 @@ my $debug = 0;
 sub new
 {
     my $className = shift;
+    my $interface = shift;
+    my $params    = shift;
+
     return undef if(ref $className);
 
     if($debug) { print STDERR "In UMLS::Similarity::lin->new()\n"; }
 
-    my $interface = shift;
-
     my $self = {};
  
    # Bless the object.
@@ -70,6 +71,43 @@ sub new
 	print STDERR "The UMLS::Similarity::ErrorHandler did not load properly\n";
 	exit;
     }
+       
+    # set the propagation/frequency information
+    $interface->setPropagationParameters($params);
+    
+    #  if the icpropagation or icfrequency option is not 
+    #  defined set the default options for icpropagation
+    if( (!defined $params->{"icpropagation"}) &&
+	(!defined $params->{"icfrequency"}) ) {
+	
+	print STDERR "Setting default propagation file\n";
+
+	#  get the icfrequency file
+	my $icfrequency = ""; foreach my $path (@INC) {
+	    if(-e $path."/UMLS/icfrequency.default.dat") { 
+		$icfrequency = $path."/UMLS/icfrequency.default.dat";
+	    }
+	    elsif(-e $path."\\UMLS\\icfrequency.default.dat") { 
+		$icfrequency =  $path."\\UMLS\\icfrequency.default.dat";
+	    }
+	}
+	
+	#  set the cuilist
+	my $fhash = $interface->getCuiList();
+	
+	#  load the frequency counts
+	open(FILE, $icfrequency) || die "Could not open $icfrequency\n";
+	while(<FILE>) { 
+	    chomp;
+	    my ($cui, $freq) = split/<>/;
+	    if(exists ${$fhash}{$cui}) { 
+		${$fhash}{$cui} = $freq;
+	    }
+	}
+	
+	#  propagate the counts
+	my $phash = $interface->propagateCounts($fhash);
+    }
     
     return $self;
 }
